run_main

Function run_main 

pub fn run_main() -> Result<(), Box<dyn Error>>
Run the devshell using process args and standard I/O (for the binary).

Errors

Returns an error if usage is wrong or I/O fails critically.