pub fn read_host_text(path: &Path) -> Result<String>Expand description
Read a host file and decode as for decode_host_text_bytes.
Errors
I/O errors from std::fs::read, or io::ErrorKind::InvalidData if text is not valid.
pub fn read_host_text(path: &Path) -> Result<String>Read a host file and decode as for decode_host_text_bytes.
I/O errors from std::fs::read, or io::ErrorKind::InvalidData if text is not valid.