pub fn parse_script(lines: &[String]) -> Result<Vec<ScriptStmt>, ParseError>Expand description
Parse logical lines into a list of script statements.
Errors
Returns ParseError on unclosed if/for/while or invalid syntax.
pub fn parse_script(lines: &[String]) -> Result<Vec<ScriptStmt>, ParseError>Parse logical lines into a list of script statements.
Returns ParseError on unclosed if/for/while or invalid syntax.